==> 4.7.4.tar.gz: terraform-provider-decort/samples/cloudbroker/account/data_account_list_deleted/main.tf <==
/*
Пример использования
Получение информации об удаленных аккаунтах
Информация предоставляется только по аккаунтам, удаленным без флага permanently
*/

#Расскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    decort = {
      source  = "basis/decort/decort"
      version = "<VERSION>"
    }
  }
}
*/

provider "decort" {
  authenticator = "decs3o"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "decort_cb_account_list_deleted" "adl" {
  #сортировка по одному из поддерживаемых полей
  #опциональный параметр
  #формат - "+поле" по возрастанию / "-поле" по убыванию
  #тип - строка
  #sort_by = "+name"

  #номер страницы для отображения
  #опциональный параметр
  #если не задан - выводятся все доступные данные
  #тип - целое число
  #page = 2

  #размер страницы
  #опциональный параметр
  #если не задан - выводятся все доступные данные
  #тип - целое число
  #size = 3

  #фильтр по id аккаунта
  #опциональный параметр
  #тип - целое число
  #by_id = 100

  #фильтр по имени аккаунта
  #опциональный параметр
  #тип - строка
  #name = "test"

  #фильтр по ACL
  #опциональный параметр
  #тип - строка
  #acl = "test"
  
}

output "test" {
  value = data.decort_cb_account_list_deleted.adl
}

==> 4.9.0.tar.gz: terraform-provider-decort/samples/cloudbroker/account/data_account_list_deleted/main.tf <==
/*
Пример использования
Получение информации об удаленных аккаунтах
Информация предоставляется только по аккаунтам, удаленным без флага permanently
*/

#Раскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    decort = {
      source  = "basis/decort/decort"
      version = "<VERSION>"
    }
  }
}
*/

provider "decort" {
  authenticator = "decs3o"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "decort_cb_account_list_deleted" "adl" {
  #сортировка по одному из поддерживаемых полей
  #опциональный параметр
  #формат - "+поле" по возрастанию / "-поле" по убыванию
  #тип - строка
  #sort_by = "+name"

  #номер страницы для отображения
  #опциональный параметр
  #если не задан - выводятся все доступные данные
  #тип - целое число
  #page = 2

  #размер страницы
  #опциональный параметр
  #если не задан - выводятся все доступные данные
  #тип - целое число
  #size = 3

  #фильтр по id аккаунта
  #опциональный параметр
  #тип - целое число
  #by_id = 100

  #фильтр по имени аккаунта
  #опциональный параметр
  #тип - строка
  #name = "test"

  #фильтр по ACL
  #опциональный параметр
  #тип - строка
  #acl = "test"
  
}

output "test" {
  value = data.decort_cb_account_list_deleted.adl
}
